4-Class motor imagery (Pacman) — BCI-Framework documentation

# 4-Class motor imagery (Pacman)

Implemented through extensions systems in the PacmanMotorImagery module.

This cue-based BCI paradigm consisted of up to four different motor imagery tasks, represented by the classic Pacman character displacements and separated with an asynchronous break. This paradigm implements a clean interface, unlike the game-like design used in 1.

## Configuration options

Cues:
Is possible to select up to 4 classes, represented by one arrow. All 4 classes are active by default.
Trials per class:
How many trials per class will contain the run. Between 1 and 100, 10 by default.
Stimulus onset asynchronously:
To prevent fixed time between trials. A range between 1000 and 3000 ms, (2000-3000) by default. This means that for each trial a random number (with uniform distribution) is generated between this range and used as inter stimulus interval.

### References

1

  Serafeim Perdikis, Robet Leeb, and José del R Millán. Subject-oriented training for motor imagery brain-computer interfaces. In 2014 36th Annual International Conference of the IEEE Engineering in Medicine and Biology Society, 1259–1262. IEEE, 2014.